#!/bin/bash
CODE=31c2a41ec61f3603587178027e7dc6bc791fa173
MOUNTPOINT=/mnt/usb
FILE=esia_unity_reset.txt
LOG=esia_unity_reset.log

DEFAULT_SYSTEM=restart
DEFAULT_RESET=yes

if [ -z "$DEVNAME" ]
then 
	DEVICE=/dev/sda # Pour des tests
else
	DEVICE=$DEVNAME #Variable globale settée par udev
fi

echo "Detected device $DEVICE"

PARTITIONS=$(lsblk -fPp $DEVICE|egrep -i 'FSTYPE="(ext[0-9]+|.?fat|ntfs)"'|grep 'MOUNTPOINT=""'|sed -e 's/NAME="\([^"]*\)".*/\1/g')
echo "Partitions : $PARTITIONS"

mkdir -p $MOUNTPOINT
for PART in $PARTITIONS
do
	mount $PART $MOUNTPOINT
	if [ -f "$MOUNTPOINT/$FILE" ] && [ -r "$MOUNTPOINT/$FILE" ]; then
		echo "File found"
		FILE_CODE=$(cat /mnt/usb/esia_unity_reset.txt |egrep -v "#.*"|grep code|cut -d"=" -f2)
		FILE_SYSTEM=$(cat /mnt/usb/esia_unity_reset.txt |egrep -v "#.*"|grep system|cut -d"=" -f2)
		FILE_RESET=$(cat /mnt/usb/esia_unity_reset.txt |egrep -v "#.*"|grep reset|cut -d"=" -f2)
	fi

	if [ "$CODE" == "$FILE_CODE" ]; then
		echo "File code detected"
		if [ -z "$FILE_RESET" ]; then
                        RESET=$DEFAULT_RESET
			echo "Use default reset=$RESET"
                else
                        RESET=$FILE_RESET
			echo "Use file reset=$RESET"
                fi

		if [ -z "$FILE_SYSTEM" ]; then
			SYSTEM=$DEFAULT_SYSTEM
			echo "Use default system=$SYSTEM"
		else
			SYSTEM=$FILE_SYSTEM
			echo "Use file system=$SYSTEM"
		fi

		DATE=$(date)
		echo "Reset started at $DATE (Unity time)" |tee $MOUNTPOINT/$LOG

		case $RESET in
			yes)
				/usr/sbin/esia-reset-gesa yes
				echo "Network config reset to default"| tee -a  $MOUNTPOINT/$LOG
				;;
			no)
				echo "Network config not reset to default" | tee -a  $MOUNTPOINT/$LOG
				;;
			*)
				echo "Unknown parameter for reset" | tee -a $MOUNTPOINT/$LOG
				;;
		esac

		#Shutdown cancel if UPTIME is < 2 minutes
		UPTIME=$(uptime -p|sed -e "s/[^0-9]*\([0-9]*\) minutes/\1/g")
		if [ $UPTIME -lt 2 ]; then
			echo "uptime < 2 minutes too small" | tee -a $MOUNTPOINT/$LOG
			SYSTEM=none
		fi 
		
		case $SYSTEM in
			shutdown)
				shutdown -h
				echo "System shutdown" | tee -a $MOUNTPOINT/$LOG
				;;
			restart)
				shutdown -r
				echo "System restart" | tee -a $MOUNTPOINT/$LOG
				;;
			none)
				echo "No system shutdown" | tee -a $MOUNTPOINT/$LOG
				if [ "$RESET" == "yes" ]; then 
					/etc/init.d/network_conf.pl restart
				fi
				;;
			*)
				echo "Unknown parameter for system" | tee -a $MOUNTPOINT/$LOG
				if [ "$RESET" == "yes" ]; then 
                                        /etc/init.d/network_conf.pl restart
                                fi
				;;
		esac
	fi

	umount $MOUNTPOINT

	if [ "$CODE" == "$FILE_CODE" ]; then
		break
	fi
done
rmdir $MOUNTPOINT
